@@ -36,6 +36,17 @@ sub _recurse_directory {
         return @files;
 }
 
+sub render {
+        my ($self, $t, $data) = @_;
+	my $template = $t->captured->[0] || $data->template || $t->template || $t->req;
+	$template = 'html/' . $template . '.html' if ($template !~ m/\.[^\.]+$/);
+	my $allowed = $self->allowed;
+	my ($mime) = $template =~ m/($allowed)$/;
+	return $t->logError('Invalid file mime type for file: ' . $template, 500, 1) unless $mime && $self->mime->$mime;
+	return $t->logError('File not found: ' . $template, 500, 1) unless $self->memory_cached_resourcess->{$template};
+	return ($self->mime->$mime, $self->memory_cached_resources->{$template});
+}
+
 1;
 
 =head1 NAME
@@ -46,7 +57,7 @@ Terse::View::Static::Memory - Serve static resources in memory view
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
